netapp_ontap.models.nfs_service_protocol API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.nfs_service_protocol`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NfsServiceProtocolSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NfsServiceProtocol object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `v3_64bit_identifiers_enabled GET POST PATCH`

    Specifies whether 64-bit support for NFSv3 FSIDs and file IDs is enabled.

  `v3_enabled GET POST PATCH`

    Specifies whether NFSv3 protocol is enabled.

  `v40_enabled GET POST PATCH`

    Specifies whether NFSv4.0 protocol is enabled.

  `v40_features GET POST PATCH`

    The v40_features field of the nfs_service_protocol.

  `v41_enabled GET POST PATCH`

    Specifies whether NFSv4.1 or later protocol is enabled.

  `v41_features GET POST PATCH`

    The v41_features field of the nfs_service_protocol.

  `v4_64bit_identifiers_enabled GET POST PATCH`

    Specifies whether 64-bit support for NFSv4.x FSIDs and file IDs is enabled.

  `v4_id_domain GET POST PATCH`

    Specifies the domain portion of the string form of user and group names as defined by the NFSv4 protocol.